# STPN
This is the official homepage for SpatioTemporal Pattern Network (STPN) PyPi releases

## STPN Flowchart



## To-do
- [x] Multi-target
- [ ] Complete demo
- [ ] Link STPN Papers
- [ ] Release new version in PyPi
- [ ] Doc explaining different discetization
- [ ] Doc explaining depth, tau and complexity
- [ ] Flowchart explaining STPN process
- [ ] Use UCI dataset as demo
- [ ] Discuss get_close_match() in util.py
- [ ] Test pd.crosstab() missing states when constructing TM
- [ ] Modify inference() to optionally return probabilities
- [ ] Update eval_() for multiclass results and add results saving option






## Author
- [Sin Yong Tan](https://github.com/tsyong98)